#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>

from dataclasses import dataclass


@dataclass
class DefocusAnalyzeResult:
    stream_url: str
    snapshot_done_at: float
    analyzed_at: float
    snapshot_file_id: str
    reference_image_file_ids: list[str]
    comparison_stopped_on_index: int
    least_freq_diff: float | None
    is_defocused: bool
